@@ -14,6 +14,7 @@
 #include <QCommandLineParser>
 #include <QDebug>
 #include <QDir>
+#include <QIcon>
 #include <QUrl>
 
 #include <KAboutData>
@@ -25,9 +26,6 @@
 
 int main(int argc, char **argv)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     Dragon::PlayerApplication app(argc, argv);
     KCrash::initialize();
 
@@ -53,6 +51,8 @@ int main(int argc, char **argv)
 
     KAboutData::setApplicationData(aboutData);
 
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("dragonplayer")));
+
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 
